8186462: [Graal] build Graal regardless AOT build
authorkvn
Tue, 29 Aug 2017 10:24:10 -0700
changeset 47056 a78c08ee61c5
parent 47055 58510a7115e4
child 47057 6ef313e5ad8d
child 47058 85aaac5701da
8186462: [Graal] build Graal regardless AOT build Reviewed-by: twisti, thartmann, erikj
common/autoconf/generated-configure.sh
common/autoconf/hotspot.m4
--- a/common/autoconf/hotspot.m4	Mon Aug 28 21:46:12 2017 +0200
+++ b/common/autoconf/hotspot.m4	Tue Aug 29 10:24:10 2017 -0700
@@ -335,8 +335,12 @@
     fi
     INCLUDE_GRAAL="true"
   else
-    # By default enable graal build where AOT is available
-    if test "x$ENABLE_AOT" = "xtrue"; then
+    # By default enable graal build on linux-x64 or where AOT is available.
+    # graal build requires jvmci.
+    if test "x$JVM_FEATURES_jvmci" = "xjvmci" && \
+        (test "x$OPENJDK_TARGET_CPU" = "xx86_64" && \
+         test "x$OPENJDK_TARGET_OS" = "xlinux" || \
+         test "x$ENABLE_AOT" = "xtrue") ; then
       AC_MSG_RESULT([yes])
       JVM_FEATURES_graal="graal"
       INCLUDE_GRAAL="true"
--- a/common/autoconf/generated-configure.sh	Mon Aug 28 21:46:12 2017 +0200
+++ b/common/autoconf/generated-configure.sh	Tue Aug 29 10:24:10 2017 -0700
@@ -5151,7 +5151,7 @@
 #CUSTOM_AUTOCONF_INCLUDE
 
 # Do not change or remove the following line, it is needed for consistency checks:
-DATE_WHEN_GENERATED=1503919695
+DATE_WHEN_GENERATED=1504027321
 
 ###############################################################################
 #
@@ -65798,8 +65798,12 @@
     fi
     INCLUDE_GRAAL="true"
   else
-    # By default enable graal build where AOT is available
-    if test "x$ENABLE_AOT" = "xtrue"; then
+    # By default enable graal build on linux-x64 or where AOT is available.
+    # graal build requires jvmci.
+    if test "x$JVM_FEATURES_jvmci" = "xjvmci" && \
+        (test "x$OPENJDK_TARGET_CPU" = "xx86_64" && \
+         test "x$OPENJDK_TARGET_OS" = "xlinux" || \
+         test "x$ENABLE_AOT" = "xtrue") ; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
 $as_echo "yes" >&6; }
       JVM_FEATURES_graal="graal"